@@ -23,6 +23,7 @@
 #define __GTKSOURCEMARK_H__
 
 #include <gtk/gtk.h>
+#include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
 
@@ -33,7 +34,6 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_IS_MARK_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_SOURCE_TYPE_MARK))
 #define GTK_SOURCE_MARK_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_SOURCE_TYPE_MARK, GtkSourceMarkClass))
 
-typedef struct _GtkSourceMark GtkSourceMark;
 typedef struct _GtkSourceMarkClass GtkSourceMarkClass;
 
 typedef struct _GtkSourceMarkPrivate GtkSourceMarkPrivate;
@@ -54,15 +54,21 @@ struct _GtkSourceMarkClass
 	void (*_gtk_source_reserved2) (void);
 };
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GType		 gtk_source_mark_get_type (void) G_GNUC_CONST;
 
-GtkSourceMark   *gtk_source_mark_new		(const gchar	*name, 
+GTK_SOURCE_AVAILABLE_IN_ALL
+GtkSourceMark   *gtk_source_mark_new		(const gchar	*name,
 						 const gchar	*category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 const gchar	*gtk_source_mark_get_category	(GtkSourceMark	*mark);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceMark	*gtk_source_mark_next		(GtkSourceMark	*mark,
 						 const gchar	*category);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceMark	*gtk_source_mark_prev		(GtkSourceMark	*mark,
 						 const gchar	*category);
 
