@@ -1,43 +1,43 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- *  gtksourceview.h
+ * gtksourceview.h
+ * This file is part of GtkSourceView
  *
- *  Copyright (C) 2001 - Mikael Hermansson <tyan@linux.se> and
- *  Chris Phelps <chicane@reninet.com>
+ * Copyright (C) 2001 - Mikael Hermansson <tyan@linux.se> and
+ *                       Chris Phelps <chicane@reninet.com>
+ * Copyright (C) 2003 - Gustavo Giráldez and Paolo Maggi
  *
- *  Copyright (C) 2003 - Gustavo Giráldez and Paolo Maggi
+ * GtkSourceView is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * GtkSourceView is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef __GTK_SOURCE_VIEW_H__
 #define __GTK_SOURCE_VIEW_H__
 
 #include <gtk/gtk.h>
-
-#include <gtksourceview/gtksourcebuffer.h>
-#include <gtksourceview/gtksourcecompletion.h>
-#include <gtksourceview/gtksourcegutter.h>
+#include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
 
-#define GTK_TYPE_SOURCE_VIEW             (gtk_source_view_get_type ())
-#define GTK_SOURCE_VIEW(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_SOURCE_VIEW, GtkSourceView))
-#define GTK_SOURCE_VIEW_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_SOURCE_VIEW, GtkSourceViewClass))
-#define GTK_IS_SOURCE_VIEW(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_SOURCE_VIEW))
-#define GTK_IS_SOURCE_VIEW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SOURCE_VIEW))
-#define GTK_SOURCE_VIEW_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_SOURCE_VIEW, GtkSourceViewClass))
+#define GTK_SOURCE_TYPE_VIEW             (gtk_source_view_get_type ())
+#define GTK_SOURCE_VIEW(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_SOURCE_TYPE_VIEW, GtkSourceView))
+#define GTK_SOURCE_VIEW_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_SOURCE_TYPE_VIEW, GtkSourceViewClass))
+#define GTK_SOURCE_IS_VIEW(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_SOURCE_TYPE_VIEW))
+#define GTK_SOURCE_IS_VIEW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_SOURCE_TYPE_VIEW))
+#define GTK_SOURCE_VIEW_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_SOURCE_TYPE_VIEW, GtkSourceViewClass))
+
+typedef struct _GtkSourceViewClass GtkSourceViewClass;
+typedef struct _GtkSourceViewPrivate GtkSourceViewPrivate;
 
 /**
  * GtkSourceViewGutterPosition:
@@ -45,21 +45,16 @@ G_BEGIN_DECLS
  * renderer
  * @GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS: the gutter position of the marks
  * renderer
- **/
+ */
 typedef enum
 {
 	GTK_SOURCE_VIEW_GUTTER_POSITION_LINES = -30,
 	GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS = -20
 } GtkSourceViewGutterPosition;
 
-typedef struct _GtkSourceView GtkSourceView;
-typedef struct _GtkSourceViewClass GtkSourceViewClass;
-
-typedef struct _GtkSourceViewPrivate GtkSourceViewPrivate;
-
 struct _GtkSourceView
 {
-	GtkTextView           parent;
+	GtkTextView parent;
 
 	GtkSourceViewPrivate *priv;
 };
@@ -70,7 +65,7 @@ struct _GtkSourceViewClass
 
 	void (*undo) (GtkSourceView *view);
 	void (*redo) (GtkSourceView *view);
-	void (*line_mark_activated) (GtkSourceView *view, 
+	void (*line_mark_activated) (GtkSourceView *view,
 	                             GtkTextIter   *iter,
 	                             GdkEvent      *event);
 	void (*show_completion) (GtkSourceView *view);
@@ -78,8 +73,10 @@ struct _GtkSourceViewClass
 	                    gboolean       copy,
 	                    gint           step);
 
+	void (*move_words) (GtkSourceView *view,
+	                    gint           step);
+
 	/* Padding for future expansion */
-	void (*_gtk_source_reserved1) (void);
 };
 
 /**
@@ -93,7 +90,7 @@ struct _GtkSourceViewClass
  * non-whitespace character on the second press.
  * @GTK_SOURCE_SMART_HOME_END_ALWAYS: always move to the first/last
  * non-whitespace character when the HOME/END keys are pressed.
- **/
+ */
 typedef enum
 {
 	GTK_SOURCE_SMART_HOME_END_DISABLED,
@@ -127,152 +124,159 @@ typedef enum
 	GTK_SOURCE_DRAW_SPACES_LEADING    = 1 << 4,
 	GTK_SOURCE_DRAW_SPACES_TEXT       = 1 << 5,
 	GTK_SOURCE_DRAW_SPACES_TRAILING   = 1 << 6,
-	GTK_SOURCE_DRAW_SPACES_ALL        = (GTK_SOURCE_DRAW_SPACES_SPACE   | \
-	                                     GTK_SOURCE_DRAW_SPACES_TAB     | \
-	                                     GTK_SOURCE_DRAW_SPACES_NEWLINE | \
-	                                     GTK_SOURCE_DRAW_SPACES_NBSP | \
-	                                     GTK_SOURCE_DRAW_SPACES_LEADING | \
-	                                     GTK_SOURCE_DRAW_SPACES_TEXT | \
-	                                     GTK_SOURCE_DRAW_SPACES_TRAILING)
+	GTK_SOURCE_DRAW_SPACES_ALL        = 0x7f
 } GtkSourceDrawSpacesFlags;
 
+GTK_SOURCE_AVAILABLE_IN_ALL
+GType		 gtk_source_view_get_type		(void) G_GNUC_CONST;
 
-GType		 gtk_source_view_get_type 		(void) G_GNUC_CONST;
+GTK_SOURCE_AVAILABLE_IN_ALL
+GtkWidget	*gtk_source_view_new			(void);
 
-/* Constructors */
-GtkWidget 	*gtk_source_view_new 			(void);
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkWidget 	*gtk_source_view_new_with_buffer	(GtkSourceBuffer *buffer);
 
-/* Properties */
-void 		 gtk_source_view_set_show_line_numbers 	(GtkSourceView   *view,
+GTK_SOURCE_AVAILABLE_IN_ALL
+void		 gtk_source_view_set_show_line_numbers 	(GtkSourceView   *view,
 							 gboolean         show);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean 	 gtk_source_view_get_show_line_numbers 	(GtkSourceView   *view);
 
-void 		 gtk_source_view_set_tab_width          (GtkSourceView   *view,
+GTK_SOURCE_AVAILABLE_IN_ALL
+void		 gtk_source_view_set_tab_width          (GtkSourceView   *view,
 							 guint            width);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 guint            gtk_source_view_get_tab_width          (GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_indent_width 	(GtkSourceView   *view,
 							 gint             width);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gint		 gtk_source_view_get_indent_width	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_auto_indent 	(GtkSourceView   *view,
 							 gboolean         enable);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean	 gtk_source_view_get_auto_indent 	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_insert_spaces_instead_of_tabs
 							(GtkSourceView   *view,
 							 gboolean         enable);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean	 gtk_source_view_get_insert_spaces_instead_of_tabs
 							(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_indent_on_tab 	(GtkSourceView   *view,
 							 gboolean         enable);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean	 gtk_source_view_get_indent_on_tab 	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_3_16
+void		 gtk_source_view_indent_lines		(GtkSourceView   *view,
+							 GtkTextIter     *start,
+							 GtkTextIter     *end);
+
+GTK_SOURCE_AVAILABLE_IN_3_16
+void		 gtk_source_view_unindent_lines		(GtkSourceView   *view,
+							 GtkTextIter     *start,
+							 GtkTextIter     *end);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_highlight_current_line
 							(GtkSourceView   *view,
-							 gboolean         show);
+							 gboolean         highlight);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean 	 gtk_source_view_get_highlight_current_line
 							(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_show_right_margin 	(GtkSourceView   *view,
 							 gboolean         show);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean 	 gtk_source_view_get_show_right_margin 	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_right_margin_position
 					 		(GtkSourceView   *view,
 							 guint            pos);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 guint		 gtk_source_view_get_right_margin_position
 					 		(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void 		 gtk_source_view_set_show_line_marks    (GtkSourceView   *view,
 							 gboolean         show);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean	 gtk_source_view_get_show_line_marks    (GtkSourceView   *view);
 
-#ifndef GTKSOURCEVIEW_DISABLE_DEPRECATED
-void		 gtk_source_view_set_mark_category_pixbuf
-							(GtkSourceView   *view,
-							const gchar      *category,
-							GdkPixbuf        *pixbuf) G_GNUC_DEPRECATED;
-#endif
+GTK_SOURCE_AVAILABLE_IN_ALL
+void             gtk_source_view_set_mark_attributes    (GtkSourceView           *view,
+                                                         const gchar             *category,
+                                                         GtkSourceMarkAttributes *attributes,
+                                                         gint                     priority);
 
-void             gtk_source_view_set_mark_category_icon_from_pixbuf
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 GdkPixbuf       *pixbuf);
+GTK_SOURCE_AVAILABLE_IN_ALL
+GtkSourceMarkAttributes *
+                 gtk_source_view_get_mark_attributes    (GtkSourceView           *view,
+                                                         const gchar             *category,
+                                                         gint                    *priority);
 
-void             gtk_source_view_set_mark_category_icon_from_stock
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 const gchar     *stock_id);
+GTK_SOURCE_AVAILABLE_IN_3_18
+void		 gtk_source_view_set_smart_backspace	(GtkSourceView   *view,
+							 gboolean        smart_backspace);
 
-void             gtk_source_view_set_mark_category_icon_from_icon_name
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 const gchar     *name);
-
-#ifndef GTKSOURCEVIEW_DISABLE_DEPRECATED
-GdkPixbuf	*gtk_source_view_get_mark_category_pixbuf
-							(GtkSourceView   *view,
-				       			 const gchar     *category) G_GNUC_DEPRECATED;
-#endif
-
-void             gtk_source_view_set_mark_category_background
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 const GdkColor  *color);
-gboolean         gtk_source_view_get_mark_category_background
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 GdkColor        *dest);
-
-/**
- * GtkSourceViewMarkTooltipFunc:
- * @mark: the #GtkSourceMark
- * @user_data: user data pointer which was passed to gtk_source_view_set_mark_category_tooltip_func()
- *
- * Function type for setting up a tooltip for #GtkSourceMark.
- * Returns: a newly-allocated string that is going to be shown as tooltip text.
- */
-typedef gchar *  (*GtkSourceViewMarkTooltipFunc)	(GtkSourceMark	*mark,
-							 gpointer	 user_data);
-void             gtk_source_view_set_mark_category_tooltip_func
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 GtkSourceViewMarkTooltipFunc func,
-							 gpointer	  user_data,
-							 GDestroyNotify   user_data_notify);
-void		 gtk_source_view_set_mark_category_tooltip_markup_func
-							(GtkSourceView   *view,
-							const gchar     *category,
-							GtkSourceViewMarkTooltipFunc markup_func,
-							gpointer         user_data,
-							GDestroyNotify   user_data_notify);
-
-void             gtk_source_view_set_mark_category_priority
-							(GtkSourceView   *view,
-							 const gchar     *category,
-							 gint priority);
-gint		 gtk_source_view_get_mark_category_priority
-							(GtkSourceView   *view,
-				       			 const gchar     *category);
+GTK_SOURCE_AVAILABLE_IN_3_18
+gboolean	 gtk_source_view_get_smart_backspace	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void		 gtk_source_view_set_smart_home_end	(GtkSourceView             *view,
-							 GtkSourceSmartHomeEndType  smart_he);
+							 GtkSourceSmartHomeEndType  smart_home_end);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceSmartHomeEndType
 		 gtk_source_view_get_smart_home_end	(GtkSourceView   *view);
 
-void		 gtk_source_view_set_draw_spaces	(GtkSourceView   *view,
-							 GtkSourceDrawSpacesFlags flags);
+GTK_SOURCE_AVAILABLE_IN_ALL
+void		 gtk_source_view_set_draw_spaces	(GtkSourceView            *view,
+							 GtkSourceDrawSpacesFlags  flags);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceDrawSpacesFlags
-		gtk_source_view_get_draw_spaces		(GtkSourceView   *view);
+		 gtk_source_view_get_draw_spaces	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
+guint		 gtk_source_view_get_visual_column	(GtkSourceView     *view,
+							 const GtkTextIter *iter);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceCompletion *
-		gtk_source_view_get_completion		(GtkSourceView   *view);
+		 gtk_source_view_get_completion		(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceGutter *gtk_source_view_get_gutter		(GtkSourceView     *view,
                                                          GtkTextWindowType  window_type);
 
+GTK_SOURCE_AVAILABLE_IN_3_16
+void		 gtk_source_view_set_background_pattern	(GtkSourceView                  *view,
+                                                         GtkSourceBackgroundPatternType  background_pattern);
+
+GTK_SOURCE_AVAILABLE_IN_3_16
+GtkSourceBackgroundPatternType
+		 gtk_source_view_get_background_pattern	(GtkSourceView   *view);
+
 G_END_DECLS
-#endif				/* end of SOURCE_VIEW_H__ */
+
+#endif /* end of __GTK_SOURCE_VIEW_H__ */
